@@ -8,6 +8,7 @@ import os
 import errno
 import math
 
+from m3u8.protocol import ext_x_start
 from m3u8.parser import parse, format_date_time
 from m3u8.mixins import BasePathMixin, GroupedBasePathMixin
 
@@ -176,7 +177,10 @@ class M3U8(object):
                                          uri=ifr_pl['uri'],
                                          iframe_stream_info=ifr_pl['iframe_stream_info'])
                                         )
-        self.segment_map_uri = self.data.get('segment_map_uri')
+        self.segment_map = self.data.get('segment_map')
+
+        start = self.data.get('start', None)
+        self.start = start and Start(**start)
 
     def __unicode__(self):
         return self.dumps()
@@ -251,6 +255,8 @@ class M3U8(object):
             output.append('#EXT-X-PROGRAM-DATE-TIME:' + format_date_time(self.program_date_time))
         if not (self.playlist_type is None or self.playlist_type == ''):
             output.append('#EXT-X-PLAYLIST-TYPE:%s' % str(self.playlist_type).upper())
+        if self.start:
+            output.append(str(self.start))
         if self.is_i_frames_only:
             output.append('#EXT-X-I-FRAMES-ONLY')
         if self.is_variant:
@@ -278,7 +284,8 @@ class M3U8(object):
     def _create_sub_directories(self, filename):
         basename = os.path.dirname(filename)
         try:
-            os.makedirs(basename)
+            if basename:
+                os.makedirs(basename)
         except OSError as error:
             if error.errno != errno.EEXIST:
                 raise
@@ -479,6 +486,7 @@ class Playlist(BasePathMixin):
 
         self.stream_info = StreamInfo(
             bandwidth=stream_info['bandwidth'],
+            closed_captions=stream_info.get('closed_captions'),
             average_bandwidth=stream_info.get('average_bandwidth'),
             program_id=stream_info.get('program_id'),
             resolution=resolution_pair,
@@ -496,6 +504,8 @@ class Playlist(BasePathMixin):
         stream_inf = []
         if self.stream_info.program_id:
             stream_inf.append('PROGRAM-ID=%d' % self.stream_info.program_id)
+        if self.stream_info.closed_captions:
+            stream_inf.append('CLOSED-CAPTIONS=%s' % self.stream_info.closed_captions)
         if self.stream_info.bandwidth:
             stream_inf.append('BANDWIDTH=%d' % self.stream_info.bandwidth)
         if self.stream_info.average_bandwidth:
@@ -547,6 +557,7 @@ class IFramePlaylist(BasePathMixin):
 
         self.iframe_stream_info = StreamInfo(
             bandwidth=iframe_stream_info.get('bandwidth'),
+            closed_captions=iframe_stream_info.get('closed_captions'),
             average_bandwidth=None,
             program_id=iframe_stream_info.get('program_id'),
             resolution=resolution_pair,
@@ -575,7 +586,7 @@ class IFramePlaylist(BasePathMixin):
 
 StreamInfo = namedtuple(
     'StreamInfo',
-    ['bandwidth', 'average_bandwidth', 'program_id', 'resolution', 'codecs']
+    ['bandwidth', 'closed_captions', 'average_bandwidth', 'program_id', 'resolution', 'codecs']
 )
 
 
@@ -671,6 +682,22 @@ class PlaylistList(list, GroupedBasePathMixin):
         return '\n'.join(output)
 
 
+class Start(object):
+
+    def __init__(self, time_offset, precise=None):
+        self.time_offset = float(time_offset)
+        self.precise = precise
+
+    def __str__(self):
+        output = [
+            'TIME-OFFSET=' + str(self.time_offset)
+        ]
+        if self.precise and self.precise in ['YES', 'NO']:
+            output.append('PRECISE=' + str(self.precise))
+
+        return ext_x_start + ':' + ','.join(output)
+
+
 def find_key(keydata, keylist):
     if not keydata:
         return None
