@@ -51,7 +51,7 @@ def parse(content, strict=False):
         'segments': [],
         'iframe_playlists': [],
         'media': [],
-        'keys': [],
+        'keys': []
     }
 
     state = {
@@ -137,7 +137,16 @@ def parse(content, strict=False):
             data['is_endlist'] = True
 
         elif line.startswith(protocol.ext_x_map):
-            data['segment_map_uri'] = _parse_segment_map_uri(line)
+            quoted_parser = remove_quotes_parser('uri')
+            segment_map_info = _parse_attribute_list(protocol.ext_x_map, line, quoted_parser)
+            data['segment_map'] = segment_map_info
+
+        elif line.startswith(protocol.ext_x_start):
+            attribute_parser = {
+                "time_offset": lambda x: float(x)
+            }
+            start_info = _parse_attribute_list(protocol.ext_x_start, line, attribute_parser)
+            data['start'] = start_info
 
         # Comments and whitespace
         elif line.startswith('#'):
@@ -172,7 +181,7 @@ def _parse_key(line):
 
 
 def _parse_extinf(line, data, state, lineno, strict):
-    chunks = line.replace(protocol.extinf + ':', '').split(',')
+    chunks = line.replace(protocol.extinf + ':', '').split(',', 1)
     if len(chunks) == 2:
         duration, title = chunks
     elif len(chunks) == 1:
@@ -310,14 +319,6 @@ def _parse_cueout_start(line, state, prevline):
         state['current_cue_out_duration'] = _cueout_state[1]
 
 
-def _parse_segment_map_uri(line):
-    """
-    :param line: '#EXT-X-MAP:URI="fileSequence0.mp4"'
-    :rtype: str 
-    """
-    return remove_quotes(line.replace(protocol.ext_x_map+':', '').split('=', 1)[1])
-
-
 def string_to_lines(string):
     return string.strip().replace('\r\n', '\n').split('\n')
 
