@@ -15,6 +15,24 @@ http://media.example.com/entire.ts
 #EXT-X-ENDLIST
 '''
 
+SIMPLE_PLAYLIST_WITH_START_NEGATIVE_OFFSET = '''
+#EXTM3U
+#EXT-X-TARGETDURATION:5220
+#EXT-X-START:TIME-OFFSET=-2.0
+#EXTINF:5220,
+http://media.example.com/entire.ts
+#EXT-X-ENDLIST
+'''
+
+SIMPLE_PLAYLIST_WITH_START_PRECISE = '''
+#EXTM3U
+#EXT-X-TARGETDURATION:5220
+#EXT-X-START:TIME-OFFSET=10.5,PRECISE=YES
+#EXTINF:5220,
+http://media.example.com/entire.ts
+#EXT-X-ENDLIST
+'''
+
 SIMPLE_PLAYLIST_FILENAME = abspath(
     join(dirname(__file__), 'playlists/simple-playlist.m3u8'))
 
@@ -461,6 +479,14 @@ JUNK
 #EXT-X-ENDLIST
 '''
 
+# The playlist fails if parsed as strict, but otherwise passes
+SIMPLE_PLAYLIST_TITLE_COMMA = '''
+#EXTM3U
+#EXTINF:5220,Title with a comma, end
+http://media.example.com/entire.ts
+#EXT-X-ENDLIST
+'''
+
 # Playlist with EXTINF record not ending with comma
 SIMPLE_PLAYLIST_COMMALESS_EXTINF = '''
 #EXTM3U
@@ -607,6 +633,22 @@ MAP_URI_PLAYLIST = '''#EXTM3U
 #EXT-X-MAP:URI="fileSequence0.mp4"
 '''
 
+MAP_URI_PLAYLIST_WITH_BYTERANGE = '''#EXTM3U
+#EXT-X-TARGETDURATION:2
+#EXT-X-VERSION:7
+#EXT-X-MEDIA-SEQUENCE:1
+#EXT-X-PLAYLIST-TYPE:VOD
+#EXT-X-INDEPENDENT-SEGMENTS
+#EXT-X-MAP:URI="main.mp4",BYTERANGE="812@0"
+'''
+
+MEDIA_WITHOUT_URI_PLAYLIST = '''#EXTM3U
+#EXT-X-VERSION:4
+#EXT-X-MEDIA:TYPE=AUDIO,GROUP-ID="audio-aacl-312",NAME="English",LANGUAGE="en",AUTOSELECT=YES,DEFAULT=YES,CHANNELS="2"
+#EXT-X-STREAM-INF:BANDWIDTH=364000,AVERAGE-BANDWIDTH=331000,CODECS="mp4a.40.2",AUDIO="audio-aacl-312",SUBTITLES="textstream"
+ch001-audio_312640_eng=312000.m3u8
+'''
+
 RELATIVE_PLAYLIST_FILENAME = abspath(join(dirname(__file__), 'playlists/relative-playlist.m3u8'))
 
 RELATIVE_PLAYLIST_URI = TEST_HOST + '/path/to/relative-playlist.m3u8'
