@@ -8,9 +8,12 @@
 
 import arrow
 import datetime
+
+from m3u8.protocol import ext_x_start
+
 import m3u8
 import playlists
-from m3u8.model import Segment, Key
+from m3u8.model import Segment, Key, Media
 
 
 def test_target_duration_attribute():
@@ -230,10 +233,12 @@ def test_playlists_attribute():
     data = {'playlists': [{'uri': '/url/1.m3u8',
                            'stream_info': {'program_id': 1,
                                            'bandwidth': 320000,
+                                           'closed_captions': None,
                                            'video': 'high'}},
                           {'uri': '/url/2.m3u8',
                            'stream_info': {'program_id': 1,
                                            'bandwidth': 120000,
+                                           'closed_captions': None,
                                            'codecs': 'mp4a.40.5',
                                            'video': 'low'}},
                           ],
@@ -249,6 +254,7 @@ def test_playlists_attribute():
     assert '/url/1.m3u8' == obj.playlists[0].uri
     assert 1 == obj.playlists[0].stream_info.program_id
     assert 320000 == obj.playlists[0].stream_info.bandwidth
+    assert None == obj.playlists[0].stream_info.closed_captions
     assert None == obj.playlists[0].stream_info.codecs
 
     assert None == obj.playlists[0].media[0].uri
@@ -264,6 +270,7 @@ def test_playlists_attribute():
     assert '/url/2.m3u8' == obj.playlists[1].uri
     assert 1 == obj.playlists[1].stream_info.program_id
     assert 120000 == obj.playlists[1].stream_info.bandwidth
+    assert None == obj.playlists[1].stream_info.closed_captions
     assert 'mp4a.40.5' == obj.playlists[1].stream_info.codecs
 
     assert None == obj.playlists[1].media[0].uri
@@ -690,13 +697,42 @@ def test_m3u8_should_propagate_base_uri_to_key():
     assert '/any/key.bin' == obj.keys[0].absolute_uri
 
 
+def test_base_path_with_optional_uri_should_do_nothing():
+    media = Media(type='AUDIO', group_id='audio-group', name='English')
+    assert media.uri is None
+    assert media.base_uri is None
+    media.base_path = "base_path"
+    assert media.absolute_uri is None
+    assert media.base_path is None
+
+
 def test_segment_map_uri_attribute():
     obj = m3u8.M3U8(playlists.MAP_URI_PLAYLIST)
-    assert obj.segment_map_uri == "fileSequence0.mp4"
+    assert obj.segment_map['uri'] == "fileSequence0.mp4"
+
+
+def test_segment_map_uri_attribute_with_byterange():
+    obj = m3u8.M3U8(playlists.MAP_URI_PLAYLIST_WITH_BYTERANGE)
+    assert obj.segment_map['uri'] == "main.mp4"
+
+
+def test_start_with_negative_offset():
+    obj = m3u8.M3U8(playlists.SIMPLE_PLAYLIST_WITH_START_NEGATIVE_OFFSET)
+    assert obj.start.time_offset == -2.0
+    assert obj.start.precise is None
+    assert ext_x_start + ':TIME-OFFSET=-2.0\n' in obj.dumps()
+
+
+def test_start_with_precise():
+    obj = m3u8.M3U8(playlists.SIMPLE_PLAYLIST_WITH_START_PRECISE)
+    assert obj.start.time_offset == 10.5
+    assert obj.start.precise == 'YES'
+    assert ext_x_start + ':TIME-OFFSET=10.5,PRECISE=YES\n' in obj.dumps()
 
 
 # custom asserts
 
+
 def assert_file_content(filename, expected):
     with open(filename) as fileobj:
         content = fileobj.read().strip()
